/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：28所 C++ 信息安全性设计准则
 * 项目描述：用于检查C++源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.cxx;

import org.sonar.api.config.PropertyDefinition;
import org.sonar.api.resources.AbstractLanguage;
import org.sonar.api.resources.Qualifiers;

import java.util.List;

import static java.util.Arrays.asList;


/**
 * TODO LogLanguage
 *
 * @author RenFengJiang
 * @date 2024/1/16
 */
public class LogLanguage extends AbstractLanguage {
    public static final String NAME = "LOG";
    public static final String KEY = "log";

    public static final String FILE_SUFFIXES_KEY = "sonar.log.file.suffixes";

    public static final String DEFAULT_FILE_SUFFIXES = ".log";

    public LogLanguage() {
        super(KEY, NAME);
    }

    @Override
    public String[] getFileSuffixes() {
        return new String[] {".log"};
    }


    public static List<PropertyDefinition> properties() {
        return asList(
                PropertyDefinition.builder(FILE_SUFFIXES_KEY)
                        .multiValues(true)
                        .defaultValue(DEFAULT_FILE_SUFFIXES)
                        .category("FileType")
                        .name("File Suffixes")
                        .description("List of suffixes for files to analyze.")
                        .onQualifiers(Qualifiers.PROJECT)
                        .build()
        );
    }

}
