/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：28所 C++ 信息安全性设计准则
 * 项目描述：用于检查C++源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.cxx.rules.checkers;

import com.sonar.cxx.sslr.api.AstNode;
import com.sonar.cxx.sslr.api.Grammar;
import org.sonar.check.Priority;
import org.sonar.check.Rule;
import org.sonar.cxx.parser.CxxGrammarImpl;
import org.sonar.cxx.squidbridge.annotations.ActivatedByDefault;
import org.sonar.cxx.squidbridge.annotations.SqaleConstantRemediation;
import org.sonar.cxx.squidbridge.checks.SquidCheck;

import javax.annotation.Nonnull;
import java.util.List;

/**
 * TODO 应使用目前被业界专家认为较强的经过良好审核的加密PRNG算法
 *
 * @author RenFengJiang
 * @date 2024/1/23
 */
@Rule(key = "PRNGVerifyChecker", name = "应使用目前被业界专家认为较强的经过良好审核的加密PRNG算法", description = "使用目前被业界专家认为较强的经过良好审核的加密PRNG算法，初始化随机数生成器时使用具有足够长度且不固定的种子", priority = Priority.INFO, tags = {"28suo"})
@ActivatedByDefault
@SqaleConstantRemediation("5min")
public class PRNGVerifyChecker extends SquidCheck<Grammar> {

    List<String> lists = List.of("minstd_rand0","minstd_rand","mt19937","mt19937_64","ranlux24_base","ranlux48_base","ranlux24","ranlux48","knuth_b");
    @Override
    public void init() {
        // 指定当前访问器需要访问的节点类型，functionBody（函数）主体节点
        this.subscribeTo(
                CxxGrammarImpl.declarationStatement
        );
    }

    /**
     * 访问AST节点
     *
     * @param node 要处理的AST节点，该节点类型为通过subscribeTo方法订阅的类型
     */
    @Override
    public void visitNode(@Nonnull AstNode node) {
        List<AstNode> descendants = node.getDescendants(CxxGrammarImpl.typeName);
        for (AstNode desc:descendants) {
            if(lists.contains(desc.getTokenValue())){
                getContext().createLineViolation(this, "应使用目前被业界专家认为较强的经过良好审核的加密PRNG算法", node);
                break;
            }
        }

    }
}
