/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：28所 C++ 信息安全性设计准则
 * 项目描述：用于检查C++源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.cxx.rules.checkers;

import com.sonar.cxx.sslr.api.AstNode;
import com.sonar.cxx.sslr.api.Grammar;
import org.sonar.check.Priority;
import org.sonar.check.Rule;
import org.sonar.cxx.parser.CxxGrammarImpl;
import org.sonar.cxx.squidbridge.annotations.ActivatedByDefault;
import org.sonar.cxx.squidbridge.annotations.SqaleConstantRemediation;
import org.sonar.cxx.squidbridge.checks.SquidCheck;

import javax.annotation.Nonnull;
import java.util.ArrayList;
import java.util.List;

/**
 * TODO SendMessageChecker
 *
 * @author RenFengJiang
 * @date 2024/1/18
 */
@Rule(key = "SendMessageChecker", name = "发送敏感信息前应对敏感信息进行加密", description = "发送敏感信息前对敏感信息进行加密或采用加密通信传输敏感信息", priority = Priority.INFO, tags = {"28suo"})
@ActivatedByDefault
@SqaleConstantRemediation("5min")
public class SendMessageChecker extends SquidCheck<Grammar> {
    @Override
    public void init() {
        // 指定当前访问器需要访问的节点类型，functionBody（函数）主体节点
        this.subscribeTo(
                CxxGrammarImpl.functionBody
        );
    }
    private static List<String> lists = new ArrayList(){{
        add("weapon");
        add("unit");
        add("param");
    }};


    /**
     * 访问AST节点
     *
     * @param node 要处理的AST节点，该节点类型为通过subscribeTo方法订阅的类型
     */
    @Override
    public void visitNode(@Nonnull AstNode node) {
        //创建集合存入违规敏感字段

        //获取到所有的表达式
        List<AstNode> descendants = node.getDescendants(CxxGrammarImpl.expression);
        for (AstNode des:descendants) {
            //判断表达式是否是send发送信息
            if("send".equals(des.getTokenValue())){
                //获取其中的参数
                AstNode firstDescendant = des.getFirstDescendant(CxxGrammarImpl.initializerList);
                List<AstNode> children = firstDescendant.getChildren();
                AstNode astNode = children.get(2);
                //判断其中的参数类型
                if("STRING".equals(astNode.getName())){

                }else {
                    //判斷其中是否包含敏感字段
                    if(lists.contains(astNode.getTokenValue().toLowerCase())){
                        getContext().createLineViolation(this,"发送敏感信息前应对敏感信息进行加密",des);
                    }
                }
            }
        }
    }

}
