/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：信息安全性设计准则检查插件
 * 项目描述：用于检查源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.java;

import com.keyware.sonar.java.rules.JavaSecurityDesignRulesRepository;
import com.keyware.sonar.java.rules.RulesList;
import org.sonar.api.server.profile.BuiltInQualityProfilesDefinition;
import org.sonar.plugins.html.api.HtmlConstants;
import org.sonarsource.api.sonarlint.SonarLintSide;

/**
 * 定义一个内置的Java安全设计规则集质量配置
 *
 * @author GuoXin
 * @date 2024/1/11
 */
@SonarLintSide
public class JavaSecurityDesignWayProfile implements BuiltInQualityProfilesDefinition {

    @Override
    public void define(Context context) {
        var javaWay = context.createBuiltInQualityProfile("Java信息安全性设计准则", "java");
        RulesList.getJavaRules().forEach(check -> javaWay.activateRule(JavaSecurityDesignRulesRepository.REPOSITORY_KEY, check.getSimpleName()));
        javaWay.done();

        var webWay = context.createBuiltInQualityProfile("Web信息安全性设计准则", HtmlConstants.LANGUAGE_KEY);
        RulesList.getHtmlRules().forEach(check -> webWay.activateRule(JavaSecurityDesignRulesRepository.REPOSITORY_KEY + "-" + HtmlConstants.LANGUAGE_KEY, check.getSimpleName()));
        webWay.done();

//        var cfgWay = context.createBuiltInQualityProfile("配置信息安全性设计规则", ConfigurationFileLanguage.KEY);
//        cfgWay.activateRule("config", "ConfigurationFileChecker");
//        cfgWay.activateRule("config", "SessionDateChecker");
//        cfgWay.done();
    }
}
